<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="207"/>
        <source>Custom Toolbox</source>
        <translation>Пользовательский набор инструментов</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="72"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="88"/>
        <source>Customize launcher</source>
        <translation>Настроить лаунчер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="91"/>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="97"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="161"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="167"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="180"/>
        <source>Close application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="189"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="303"/>
        <source>This is a custom launcher</source>
        <translation>Это настраиваемый лаунчер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Show this dialog at start up</source>
        <translation>Показывать этот диалог при запуске</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="341"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="255"/>
        <location filename="../src/mainwindow.cpp" line="274"/>
        <location filename="../src/mainwindow.cpp" line="295"/>
        <location filename="../src/mainwindow.cpp" line="304"/>
        <source>Execution Error</source>
        <translation>Ошибка выполнения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="255"/>
        <source>Command is empty. Cannot execute.</source>
        <translation>Команда пуста. Невозможно выполнить.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="274"/>
        <location filename="../src/mainwindow.cpp" line="295"/>
        <source>Failed to execute command: %1</source>
        <translation>Не удалось выполнить команду: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="304"/>
        <source>Failed to start program: %1</source>
        <translation>Не удалось запустить программу: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="344"/>
        <source>Open List File</source>
        <translation>Открыть файл списка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="344"/>
        <source>List Files (*.list)</source>
        <translation>Файлы списка (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="346"/>
        <source>File Selection Error</source>
        <translation>Ошибка выбора файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="346"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Не выбран файл. Приложение будет закрыто.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="352"/>
        <location filename="../src/mainwindow.cpp" line="622"/>
        <location filename="../src/mainwindow.cpp" line="780"/>
        <source>File Open Error</source>
        <translation>Ошибка открытия файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="353"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Не удалось открыть файл. Хотите попробовать снова?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="614"/>
        <source>File Not Found</source>
        <translation>Файл не найден</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="614"/>
        <source>The file %1 does not exist.</source>
        <translation>Файл %1 не существует.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="622"/>
        <source>Could not open file: </source>
        <translation>Не удалось открыть файл:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="710"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="713"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="762"/>
        <source>Directory Creation Error</source>
        <translation>Ошибка при создании каталога</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="763"/>
        <source>Could not create directory: %1</source>
        <translation>Не удалось создать каталог: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="810"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="810"/>
        <source>Editor command failed with code %1</source>
        <translation>Команда редактора не выполнена с кодом %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="711"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox - это утилита для создания пользовательского лаунчера</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="711"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="714"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="721"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="780"/>
        <source>Could not write file: %1</source>
        <translation>Не удалось записать файл: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="785"/>
        <source>File Removal Error</source>
        <translation>Ошибка удаления файла</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="785"/>
        <source>Could not remove file: %1</source>
        <translation>Не удалось удалить файл: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <source>Failed to start mx-viewer</source>
        <translation>Не удалось запустить mx-viewer</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="53"/>
        <source>Failed to start xdg-open</source>
        <translation>Не удалось запустить xdg-open</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <source>Failed to determine user name. Cannot open document.</source>
        <translation>Не удалось определить имя пользователя. Невозможно открыть документ.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="64"/>
        <source>Failed to start runuser</source>
        <translation>Не удалось запустить runuser</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="79"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="80"/>
        <location filename="../src/about.cpp" line="90"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="81"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="103"/>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Это приложение позволяет создавать персонализированные лаунчеры: бокс состоящий из кнопок/значков</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="88"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Не показывать чекбокс &quot;показывать этот диалог при запуске&quot;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="90"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Полный путь и имя файла .list, который вы хотите загрузить для настройки приложения</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <location filename="../src/about.cpp" line="53"/>
        <location filename="../src/about.cpp" line="61"/>
        <location filename="../src/about.cpp" line="64"/>
        <location filename="../src/main.cpp" line="100"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="101"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем root. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
</context>
</TS>